@@ -1,6 +1,7 @@
 class ROT13Cipher:
     def __init__(self) -> None:
         '''This is python implementation of ROT13 Cipher'''
+        pass
 
     def encrypt(self, message: str) -> str:
         result = ''
@@ -13,11 +14,4 @@ class ROT13Cipher:
         return result
 
     def decrypt(self, message: str) -> str:
-        result = ''
-        for ch in message.upper():
-            if ch.isalpha():
-                decoded = chr(((ord(ch) - ord('A') - 13 + 26) % 26) + ord('A'))
-                result += decoded
-            else:
-                result += ch
-        return result
+        return self.encrypt(message)
